@@ -17,7 +17,8 @@ void*
 MALLOC (size_t size)
 {
     void *ptr = malloc (size);
-    if (!ptr)
+    if (!ptr 
+        && (size != 0))         /* some libc don't like size == 0 */
     {
         perror ("Memory allocation failure");
         abort();
