@@ -3,7 +3,11 @@
 #endif /* HAVE_CONFIG_H */
 
 #if STDC_HEADERS
-#  include <string.h>
+#  if HAVE_STRING_H
+#    include <string.h>
+#  else
+#    include <strings.h>
+#  endif
 #else
 #  ifndef HAVE_STRRCHR
 #    define strrchr rindex
