@@ -32,7 +32,7 @@
 #endif
 
 #ifdef HAVE_CONFIG_H
-# include <config.h>
+# include "config.h"
 #endif
 
 #ifndef HAVE_GETOPT_LONG
