@@ -1,7 +1,7 @@
 /*
  * tnef.c -- extract files from microsoft TNEF format
  *
- * Copyright (C)1999, 2000 Mark Simpson <damned@world.std.com>
+ * Copyright (C)1999, 2000, 2001 Mark Simpson <damned@world.std.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@ static const char* USAGE = \
 "-f FILE, --file=FILE\tuse FILE as input ('-' == stdin)\n"
 "-C DIR, --directory=DIR\tunpack files into DIR\n"
 "-t,     --list      \tlist files, do not extract\n"
-"-w,     --interacive\task for confirmation for every action\n"
+"-w,     --interactive\task for confirmation for every action\n"
 "        --confirmation\tsame as -w\n"
 "        --overwrite \tOverwrite existing files\n"
 "        --number-backups\tIf need to overwrite file FOO, make FOO.1 instead\n"
@@ -221,6 +221,14 @@ main (int argc, char *argv[])
     {
         fp = stdin;
     }
+
+    if (fp == stdin && flags & CONFIRM)
+    {
+        fprintf (stderr, 
+                 "Cannot read file from STDIN and use "
+                 "interactive mode at the same time.\n");
+        exit (1);
+    }
     
     return parse_file (fp, out_dir, flags);
 }
