@@ -1,5 +1,5 @@
 /* strdup.h -- version of strdup for systems without it */
-/* Copyright (C) 1999, 2000 by Mark Simpson <damned@world.std.com> */
+/* Copyright (C) 1999, 2000, 2001 by Mark Simpson <damned@world.std.com> */
 #ifndef STRDUP_H
 #define STRDUP_H
 
@@ -8,7 +8,11 @@
 #endif /* HAVE_CONFIG_H */
 
 #if HAVE_STRDUP
-#  include <string.h>
+#  if HAVE_STRING_H
+#    include <string.h>
+#  else
+#    include <strings.h>
+#  endif
 #else
 extern char *
 strdup (const char *);
