@@ -35,7 +35,11 @@
 #include <unistd.h>
 
 #if STDC_HEADERS
-#  include <string.h>
+#  if HAVE_STRING_H
+#    include <string.h>
+#  else
+#    include <strings.h>
+#  endif
 #else
 #  if HAVE_MEMMOVE
 #    define memmove(d, s, n) bcopy ((s), (d), (n))
@@ -45,6 +49,7 @@
 #include <stdarg.h>
 
 #include "strdup.h"
+#include "ldiv.h"
 
 #include "tnef.h"
 
@@ -52,7 +57,7 @@
 #include "path.h"
 
 static char ident_string[] =
-"$Id: tnef.c,v 1.27 2001/04/07 14:11:55 simpson Exp $";
+"$Id: tnef.c,v 1.28 2001/08/14 01:42:28 simpson Exp $";
 
 /* To quiet compiler define tempnam */
 extern char*
@@ -819,6 +824,7 @@ file_add_mapi_attrs (File* file, MAPI_Attr** attrs)
         switch (a->name)
         {
         case MAPI_ATTACH_LONG_FILENAME:
+            if (file->name) FREE(file->name);
             file->name = munge_fname (a->values[0].len,
                                       a->values[0].data.buf);
             break;
@@ -933,6 +939,7 @@ parse_file (FILE* input_file, char* directory, int flags)
     {
         file_write (file);
         file_free (file);
+        FREE (file);
     }
     return 0;
 }
